@@ -148,7 +148,17 @@ class RouterUpdate(task_manager.Task):
 
 class RouterDelete(task_manager.Task):
     def main(self, client):
-        client.neutron_client.delete_router(**self.args)
+        return client.neutron_client.delete_router(**self.args)
+
+
+class RouterAddInterface(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.add_interface_router(**self.args)
+
+
+class RouterRemoveInterface(task_manager.Task):
+    def main(self, client):
+        client.neutron_client.remove_interface_router(**self.args)
 
 
 class GlanceImageList(task_manager.Task):
@@ -218,7 +228,7 @@ class VolumeDetach(task_manager.Task):
 
 class VolumeAttach(task_manager.Task):
     def main(self, client):
-        client.nova_client.volumes.create_server_volume(**self.args)
+        return client.nova_client.volumes.create_server_volume(**self.args)
 
 
 class NeutronSecurityGroupList(task_manager.Task):
@@ -574,3 +584,18 @@ class RecordList(task_manager.Task):
 class RecordGet(task_manager.Task):
     def main(self, client):
         return client.designate_client.records.get(**self.args)
+
+
+class RoleList(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.roles.list()
+
+
+class RoleCreate(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.roles.create(**self.args)
+
+
+class RoleDelete(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.roles.delete(**self.args)
