@@ -12,20 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import re
 import time
 
-from socket import inet_aton
-from struct import unpack
+import netifaces
 
 from shade import exc
 
 
-def _iterate_timeout(timeout, message):
+def _iterate_timeout(timeout, message, wait=2):
     """Iterate and raise an exception on timeout.
 
-    This is a generator that will continually yield and sleep for 2
-    seconds, and if the timeout is reached, will raise an exception
+    This is a generator that will continually yield and sleep for
+    wait seconds, and if the timeout is reached, will raise an exception
     with <message>.
 
     """
@@ -35,7 +33,7 @@ def _iterate_timeout(timeout, message):
     while (timeout is None) or (time.time() < start + timeout):
         count += 1
         yield count
-        time.sleep(2)
+        time.sleep(wait)
     raise exc.OpenStackCloudTimeout(message)
 
 
@@ -118,6 +116,30 @@ def _get_entity(func, name_or_id, filters):
     return entities[0]
 
 
+def normalize_keystone_services(services):
+    """Normalize the structure of keystone services
+
+    In keystone v2, there is a field called "service_type". In v3, it's
+    "type". Just make the returned dict have both.
+
+    :param list services: A list of keystone service dicts
+
+    :returns: A list of normalized dicts.
+    """
+    ret = []
+    for service in services:
+        service_type = service.get('type', service.get('service_type'))
+        new_service = {
+            'id': service['id'],
+            'name': service['name'],
+            'description': service.get('description', None),
+            'type': service_type,
+            'service_type': service_type,
+        }
+        ret.append(new_service)
+    return ret
+
+
 def normalize_nova_secgroups(groups):
     """Normalize the structure of nova security groups
 
@@ -159,42 +181,6 @@ def normalize_nova_secgroup_rules(rules):
              } for r in rules]
 
 
-def is_ipv4(ip):
-    return re.match(
-        '^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|'
-        '[01]?[0-9][0-9]?)$', ip) is not None
-
-
-def is_globally_routable_ipv4(ip):
-    # Comprehensive list of non-globally routable IPv4 networks
-    ngr_nets = (
-        ["192.168.0.0", "255.255.0.0"],     # rfc1918
-        ["172.16.0.0", "255.240.0.0"],      # rfc1918
-        ["10.0.0.0", "255.0.0.0"],          # rfc1918
-        ["192.0.2.0", "255.255.255.0"],     # rfc5737
-        ["198.51.100.0", "255.255.255.0"],  # rfc5737
-        ["203.0.113.0", "255.255.255.0"],   # rfc5737
-        ["169.254.0.0", "255.255.0.0"],     # rfc3927
-        ["100.64.0.0", "255.192.0.0"],      # rfc6598
-        ["192.0.0.0", "255.255.255.0"],     # rfc5736
-        ["192.88.99.0", "255.255.255.0"],   # rfc3068
-        ["198.18.0.0", "255.254.0.0"],      # rfc2544
-        ["224.0.0.0", "240.0.0.0"],         # rfc5771
-        ["240.0.0.0", "240.0.0.0"],         # rfc6890
-        ["0.0.0.0", "255.0.0.0"],           # rfc1700
-        ["255.255.255.255", "0.0.0.0"],     # rfc6890
-        ["127.0.0.0", "255.0.0.0"],         # rfc3330
-    )
-
-    int_ip = unpack('!I', inet_aton(ip))[0]
-    for net in ngr_nets:
-        mask = unpack('!I', inet_aton(net[1]))[0]
-        if (int_ip & mask) == unpack('!I', inet_aton(net[0]))[0]:
-            return False
-
-    return True
-
-
 def normalize_nova_floating_ips(ips):
     """Normalize the structure of Neutron floating IPs
 
@@ -273,3 +259,14 @@ def normalize_neutron_floating_ips(ips):
                   ip.get('port_id') != ''),
         status=ip['status']
     ) for ip in ips]
+
+
+def localhost_supports_ipv6():
+    """Determine whether the local host supports IPv6
+
+    We look for a default route that supports the IPv6 address family,
+    and assume that if it is present, this host has globally routable
+    IPv6 connectivity.
+    """
+
+    return netifaces.AF_INET6 in netifaces.gateways()['default']
