@@ -14,11 +14,11 @@
 
 
 import bunch
+import ipaddress
 import six
 
 from shade import exc
 from shade import _log
-from shade import _utils
 
 
 NON_CALLABLES = (six.string_types, bool, dict, int, float, list, type(None))
@@ -83,30 +83,12 @@ def get_server_private_ip(server, cloud=None):
     # Short circuit the ports/networks search below with a heavily cached
     # and possibly pre-configured network name
     if cloud:
-        int_net = cloud.get_internal_network()
-        if int_net:
+        int_nets = cloud.get_internal_networks()
+        for int_net in int_nets:
             int_ip = get_server_ip(server, key_name=int_net['name'])
             if int_ip is not None:
                 return int_ip
 
-    if cloud and cloud.has_service('network'):
-        try:
-            server_ports = cloud.search_ports(
-                filters={'device_id': server['id']})
-            nets = cloud.search_networks(
-                filters={'router:external': False, 'shared': False})
-        except Exception as e:
-            log.debug(
-                "Something went wrong talking to neutron API: "
-                "'{msg}'. Trying with Nova.".format(msg=str(e)))
-        else:
-            for net in nets:
-                for port in server_ports:
-                    if net['id'] == port['network_id']:
-                        for ip in port['fixed_ips']:
-                            if _utils.is_ipv4(ip['ip_address']):
-                                return ip['ip_address']
-
     ip = get_server_ip(server, ext_tag='fixed', key_name='private')
     if ip:
         return ip
@@ -143,35 +125,18 @@ def get_server_external_ipv4(cloud, server):
 
     # Short circuit the ports/networks search below with a heavily cached
     # and possibly pre-configured network name
-    ext_net = cloud.get_external_network()
-    if ext_net:
+    ext_nets = cloud.get_external_networks()
+    for ext_net in ext_nets:
         ext_ip = get_server_ip(server, key_name=ext_net['name'])
         if ext_ip is not None:
             return ext_ip
 
-    if cloud.has_service('network'):
-        try:
-            # Search a fixed IP attached to an external net. Unfortunately
-            # Neutron ports don't have a 'floating_ips' attribute
-            server_ports = cloud.search_ports(
-                filters={'device_id': server['id']})
-            ext_nets = cloud.search_networks(filters={'router:external': True})
-        except Exception as e:
-            log.debug(
-                "Something went wrong talking to neutron API: "
-                "'{msg}'. Trying with Nova.".format(msg=str(e)))
-            # Fall-through, trying with Nova
-        else:
-            for net in ext_nets:
-                for port in server_ports:
-                    if net['id'] == port['network_id']:
-                        for ip in port['fixed_ips']:
-                            if _utils.is_ipv4(ip['ip_address']):
-                                return ip['ip_address']
-            # The server doesn't have an interface on an external network so it
-            # can either have a floating IP or have no way to be reached from
-            # outside the cloud.
-            # Fall-through, trying with Nova
+    # Try to get a floating IP address
+    # Much as I might find floating IPs annoying, if it has one, that's
+    # almost certainly the one that wants to be used
+    ext_ip = get_server_ip(server, ext_tag='floating')
+    if ext_ip is not None:
+        return ext_ip
 
     # The cloud doesn't support Neutron or Neutron can't be contacted. The
     # server might have fixed addresses that are reachable from outside the
@@ -182,17 +147,19 @@ def get_server_external_ipv4(cloud, server):
     if ext_ip is not None:
         return ext_ip
 
-    # Try to find a globally routable IP address
+    # Nothing else works, try to find a globally routable IP address
     for interfaces in server['addresses'].values():
         for interface in interfaces:
-            if _utils.is_ipv4(interface['addr']) and \
-                    _utils.is_globally_routable_ipv4(interface['addr']):
-                return interface['addr']
-
-    # Last, try to get a floating IP address
-    ext_ip = get_server_ip(server, ext_tag='floating')
-    if ext_ip is not None:
-        return ext_ip
+            try:
+                ip = ipaddress.ip_address(interface['addr'])
+            except Exception:
+                # Skip any error, we're looking for a working ip - if the
+                # cloud returns garbage, it wouldn't be the first weird thing
+                # but it still doesn't meet the requirement of "be a working
+                # ip address"
+                continue
+            if ip.version == 4 and not ip.is_private:
+                return str(ip)
 
     return None
 
@@ -256,7 +223,8 @@ def get_groups_from_server(cloud, server, server_vars):
     return groups
 
 
-def get_hostvars_from_server(cloud, server, mounts=None):
+def expand_server_vars(cloud, server):
+    """Add clean up the server dict with information that is essential."""
     server_vars = server
     server_vars.pop('links', None)
 
@@ -265,10 +233,15 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     server_vars['public_v4'] = get_server_external_ipv4(cloud, server) or ''
     server_vars['public_v6'] = get_server_external_ipv6(server) or ''
     server_vars['private_v4'] = get_server_private_ip(server, cloud) or ''
-    if cloud.private:
+    interface_ip = None
+    if cloud.private and server_vars['private_v4']:
         interface_ip = server_vars['private_v4']
     else:
-        interface_ip = server_vars['public_v4']
+        if (server_vars['public_v6'] and cloud._local_ipv6
+            and not cloud.force_ipv4):
+            interface_ip = server_vars['public_v6']
+        else:
+            interface_ip = server_vars['public_v4']
     if interface_ip:
         server_vars['interface_ip'] = interface_ip
 
@@ -276,12 +249,25 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     # server record. Since we know them, go ahead and set them. In the case
     # where they were set previous, we use the values, so this will not break
     # clouds that provide the information
-    server_vars['accessIPv4'] = server_vars['public_v4']
+    if cloud.private and server_vars['private_v4']:
+        server_vars['accessIPv4'] = server_vars['private_v4']
+    else:
+        server_vars['accessIPv4'] = server_vars['public_v4']
     server_vars['accessIPv6'] = server_vars['public_v6']
 
     server_vars['region'] = cloud.region_name
     server_vars['cloud'] = cloud.name
 
+    az = server_vars.get('OS-EXT-AZ:availability_zone', None)
+    if az:
+        server_vars['az'] = az
+    return server_vars
+
+
+def get_hostvars_from_server(cloud, server, mounts=None):
+    """Expand additional server information useful for ansible inventory."""
+    server_vars = expand_server_vars(cloud, server)
+
     flavor_id = server['flavor']['id']
     flavor_name = cloud.get_flavor_name(flavor_id)
     if flavor_name:
@@ -317,10 +303,6 @@ def get_hostvars_from_server(cloud, server, mounts=None):
                     if 'mount' in mount:
                         vol['mount'] = mount['mount']
 
-    az = server_vars.get('OS-EXT-AZ:availability_zone', None)
-    if az:
-        server_vars['az'] = az
-
     return server_vars
 
 
@@ -333,6 +315,9 @@ def obj_to_dict(obj):
     that we can just have a plain dict of all of the values that exist in the
     nova metadata for a server.
     """
+    # If we obj_to_dict twice, don't fail, just return the bunch
+    if type(obj) == bunch.Bunch:
+        return obj
     instance = bunch.Bunch()
     for key in dir(obj):
         value = getattr(obj, key)
