@@ -67,20 +67,23 @@ class FakeProject(object):
 class FakeServer(object):
     def __init__(
             self, id, name, status, addresses=None,
-            accessIPv4='', accessIPv6=''):
+            accessIPv4='', accessIPv6='', flavor=None, image=None):
         self.id = id
         self.name = name
         self.status = status
         self.addresses = addresses
+        self.flavor = flavor
+        self.image = image
         self.accessIPv4 = accessIPv4
         self.accessIPv6 = accessIPv6
 
 
 class FakeService(object):
-    def __init__(self, id, name, type, description=''):
+    def __init__(self, id, name, type, service_type, description=''):
         self.id = id
         self.name = name
         self.type = type
+        self.service_type = service_type
         self.description = description
 
 
@@ -152,3 +155,9 @@ class FakeIdentityDomain(object):
         self.name = name
         self.description = description
         self.enabled = enabled
+
+
+class FakeRole(object):
+    def __init__(self, id, name):
+        self.id = id
+        self.name = name
