@@ -20,8 +20,6 @@ Functional tests for floating IP resource.
 """
 
 import pprint
-import random
-import string
 import time
 
 from novaclient import exceptions as nova_exc
@@ -48,10 +46,6 @@ def _iterate_timeout(timeout, message):
 class TestFloatingIP(base.TestCase):
     timeout = 60
 
-    # Generate a random name for these tests
-    new_item_name = 'test_' + ''.join(
-        random.choice(string.ascii_lowercase) for _ in range(5))
-
     def setUp(self):
         super(TestFloatingIP, self).setUp()
         self.cloud = openstack_cloud(cloud='devstack')
@@ -65,6 +59,9 @@ class TestFloatingIP(base.TestCase):
         if self.image is None:
             self.assertFalse('no sensible image available')
 
+        # Generate a random name for these tests
+        self.new_item_name = self.getUniqueString()
+
         self.addCleanup(self._cleanup_network)
         self.addCleanup(self._cleanup_servers)
 
@@ -170,7 +167,7 @@ class TestFloatingIP(base.TestCase):
             self.test_subnet = self.cloud.create_subnet(
                 subnet_name=self.new_item_name + '_subnet',
                 network_name_or_id=self.test_net['id'],
-                cidr='172.24.4.0/24',
+                cidr='10.24.4.0/24',
                 enable_dhcp=True
             )
             # Create a router
@@ -189,9 +186,17 @@ class TestFloatingIP(base.TestCase):
 
             # Select the network for creating new servers
             self.nic = {'net-id': self.test_net['id']}
+            self.addDetail(
+                'networks-neutron',
+                content.text_content(pprint.pformat(
+                    self.cloud.list_networks())))
         else:
             # ToDo: remove once we have list/get methods for nova networks
             nets = self.cloud.nova_client.networks.list()
+            self.addDetail(
+                'networks-nova',
+                content.text_content(pprint.pformat(
+                    nets)))
             self.nic = {'net-id': nets[0].id}
 
     def test_private_ip(self):
